@@ -1,5 +1,5 @@
 /*
- * $Id: volume.c,v 1.36.2.4 2003/06/14 16:56:27 srittau Exp $
+ * $Id: volume.c,v 1.36.2.7 2003/11/18 21:49:41 bfernhomberg Exp $
  *
  * Copyright (c) 1990,1993 Regents of The University of Michigan.
  * All Rights Reserved.  See COPYRIGHT.
@@ -355,7 +355,7 @@ static void volset(struct vol_option *options, char *volname, int vlen,
             if (strcasecmp(p, "prodos") == 0)
                 options[VOLOPT_FLAGS].i_value |= AFPVOL_A2VOL;
             else if (strcasecmp(p, "mswindows") == 0) {
-                options[VOLOPT_FLAGS].i_value |= AFPVOL_MSWINDOWS;
+                options[VOLOPT_FLAGS].i_value |= (AFPVOL_MSWINDOWS | AFPVOL_USEDOTS);
                 if (!options[VOLOPT_CODEPAGE].c_value)
                     options[VOLOPT_CODEPAGE].c_value =
                         get_codepage_path(nlspath, MSWINDOWS_CODEPAGE);
@@ -952,6 +952,7 @@ int		*buflen;
         ad_setentrylen( &ad, ADEID_NAME, strlen( slash ));
         memcpy(ad_entry( &ad, ADEID_NAME ), slash,
                ad_getentrylen( &ad, ADEID_NAME ));
+        ad_setdate(&ad, AD_DATE_CREATE | AD_DATE_UNIX, st->st_mtime);
         ad_flush(&ad, ADFLAGS_HF);
     }
 
